@@ -2,10 +2,11 @@ import networkx as nx
 import matplotlib.pyplot as plt
 from io import StringIO
 from networkx import algorithms
+
 try:
     import tkinter as tk
-except ImportError as e:
-    print(e)
+except ImportError as error:
+    print(error)
     print("Your Python installation may not be configured for TKinter, a dependency of Satyrn")
     print("Visit https://tkdocs.com/tutorial/install.html to install TKinter")
     exit(1)
@@ -103,9 +104,9 @@ class Cell:
         try:
             print("<" + self.name + ">")
             exec(self.content, ex_vars_copy)
-        except Exception as e:
+        except Exception as exception:
             print("Exception occurred in cell " + self.name)
-            print(e)
+            print(exception)
 
         exec_vars.update(ex_vars_copy)
 
@@ -423,9 +424,9 @@ class Graph:
 
             txtout += temp_text
 
-        for e in edges:
-            name1 = lookup_table[e[0]]
-            name2 = lookup_table[e[1]]
+        for edge in edges:
+            name1 = lookup_table[edge[0]]
+            name2 = lookup_table[edge[1]]
             txtout += "link " + name1 + " " + name2 + "\n"
 
         if self.parent.std_capture.getvalue():
@@ -497,8 +498,8 @@ class Interpreter:
             openfile = open(command[0], "r")
             self.file = openfile.readlines()
             self.run_string(self.file)
-        except Exception as e:
-            print(e)
+        except Exception as exception:
+            print(exception)
 
     def run_string(self, content):
         self.file = content
@@ -732,9 +733,9 @@ class Interpreter:
             if len(cells_list) >= 1:
                 try:
                     self.graph.execute_linear_list_of_cells(cells_list)
-                except Exception as e:
+                except Exception as exception:
                     print("There was an error executing one of the cells")
-                    print(e)
+                    print(exception)
             else:
                 self.graph.bfs_traversal_execute()
 
@@ -756,13 +757,13 @@ class Interpreter:
                 in_edges, out_edges = self.graph.get_in_out_edges(command[1])
                 if len(in_edges) > 0:
                     print("In Edges:")
-                    for e in in_edges:
-                        print(e)
+                    for edge in in_edges:
+                        print(edge)
                 print()
                 if len(out_edges) > 0:
                     print("Out Edges:")
-                    for e in out_edges:
-                        print(e)
+                    for edge in out_edges:
+                        print(edge)
                     print()
 
     def list_cells(self):
@@ -869,6 +870,3 @@ class Interpreter:
             command = self.read_input()
             if self.command_switch(command) == "break":
                 break
-
-inte = Interpreter()
-inte.run()
\ No newline at end of file
